# Generated by Django 5.2.11 on 2026-03-02 17:40

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0062_auto_20251004_0106"),
    ]

    operations = [
        migrations.CreateModel(
            name="EosReport",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("report_model", models.CharField(max_length=50)),
                ("subject_identifier", models.CharField(max_length=25)),
                ("created", models.DateTimeField(default=django.utils.timezone.now)),
                ("offschedule_datetime", models.DateTimeField(null=True)),
                ("source", models.CharField(default="", max_length=35)),
            ],
            options={
                "verbose_name": "End of study report",
                "verbose_name_plural": "End of study report",
                "db_table": "meta_reports_eosreportview",
                "managed": False,
                "default_permissions": ("view", "export", "viewallsites"),
            },
        ),
    ]
