# Generated by Django 5.2.11 on 2026-03-10 19:57

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0070_auto_20260310_2257"),
    ]

    operations = [
        migrations.CreateModel(
            name="HivExitReviewReport",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("report_model", models.CharField(max_length=50)),
                ("subject_identifier", models.CharField(max_length=25)),
                ("created", models.DateTimeField(default=django.utils.timezone.now)),
                ("source", models.CharField(default="", max_length=35)),
                ("offschedule_datetime", models.DateTimeField(null=True)),
                ("hiv_exit_data", models.CharField(default="", max_length=15)),
                ("hiv_exit_datetime", models.DateTimeField(null=True)),
                ("visit_code", models.CharField(default="", max_length=15)),
                ("visit_code_sequence", models.IntegerField(null=True)),
                ("appt_datetime", models.DateTimeField(null=True)),
                (
                    "appt_status",
                    models.CharField(
                        choices=[
                            ("new", "Not started"),
                            ("in_progress", "In Progress"),
                            ("incomplete", "Incomplete"),
                            ("done", "Done"),
                            ("cancelled", "Cancelled"),
                            ("skipped", "Skipped as per protocol"),
                        ],
                        default="",
                        max_length=25,
                        verbose_name="Status",
                    ),
                ),
                ("days", models.IntegerField(null=True)),
            ],
            options={
                "verbose_name": "HIV Exit Review report",
                "verbose_name_plural": "HIV Exit Review report",
                "db_table": "meta_reports_hivexitreviewreportview",
                "managed": False,
                "default_permissions": ("view", "export", "viewallsites"),
            },
        ),
    ]
