# Generated by Django 5.2.11 on 2026-03-16 23:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0078_auto_20260311_1533"),
    ]

    operations = [
        migrations.AddField(
            model_name="endpoints",
            name="visit_code_sequence",
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name="historicalmissingogttnote",
            name="visit_code",
            field=models.CharField(blank=True, default="", max_length=25),
        ),
        migrations.AddField(
            model_name="historicalmissingogttnote",
            name="visit_code_sequence",
            field=models.IntegerField(blank=True, default=0, verbose_name="Sequence"),
        ),
        migrations.AddField(
            model_name="missingogttnote",
            name="visit_code",
            field=models.CharField(blank=True, default="", max_length=25),
        ),
        migrations.AddField(
            model_name="missingogttnote",
            name="visit_code_sequence",
            field=models.IntegerField(blank=True, default=0, verbose_name="Sequence"),
        ),
        migrations.AlterModelTable(
            name="impsubstitutions",
            table="meta_report_impsubstitutionsview",
        ),
        migrations.AlterModelTable(
            name="missingscreeningogtt",
            table="meta_reports_missingscreeningogttview",
        ),
        migrations.AlterModelTable(
            name="onstudymissinglabvalues",
            table="meta_reports_onstudymissinglabvaluesview",
        ),
        migrations.AlterModelTable(
            name="onstudymissingvalues",
            table="meta_reports_onstudymissingvaluesview",
        ),
        migrations.AlterModelTable(
            name="patienthistorymissingbaselinecd4",
            table="meta_reports_patienthistorymissingbaselinecd4view",
        ),
        migrations.AlterModelTable(
            name="unattendedthreeinrow",
            table="meta_reports_unattendedthreeinrowview",
        ),
        migrations.AlterModelTable(
            name="unattendedthreeinrow2",
            table="meta_reports_unattendedthreeinrow2view",
        ),
        migrations.AlterModelTable(
            name="unattendedtwoinrow",
            table="meta_reports_unattendedtwoinrowview",
        ),
    ]
