# Generated by Django 5.2.11 on 2026-03-02 18:08

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0064_auto_20260302_2044"),
    ]

    operations = [
        migrations.CreateModel(
            name="OffscheduleReport",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("report_model", models.CharField(max_length=50)),
                ("subject_identifier", models.CharField(max_length=25)),
                ("created", models.DateTimeField(default=django.utils.timezone.now)),
                ("source", models.CharField(default="", max_length=35)),
                ("visit_schedule_name", models.CharField(default="", max_length=150)),
                ("schedule_name", models.CharField(default="", max_length=150)),
                ("onschedule_model", models.CharField(default="", max_length=150)),
                ("onschedule_datetime", models.DateTimeField(null=True)),
            ],
            options={
                "verbose_name": "Subjects awaiting `Off Schedule` report",
                "verbose_name_plural": "Subjects awaiting `Off Schedule` report",
                "db_table": "meta_reports_offschedulereportview",
                "managed": False,
                "default_permissions": ("view", "export", "viewallsites"),
            },
        ),
        migrations.AlterModelOptions(
            name="eosreport",
            options={
                "default_permissions": ("view", "export", "viewallsites"),
                "managed": False,
                "verbose_name": "Subjects off schedule awaiting `End of Study` report",
                "verbose_name_plural": "Subjects off schedule awaiting `End of Study` report",
            },
        ),
    ]
